.. latentcor documentation master file, created by
   sphinx-quickstart on Fri Dec 31 00:21:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

latentcor: Latent Correlation for Mixed Types of Data
=====================================================

.. toctree::

   readme
   get_started
   math
   latentcor
   reference
